@@ -203,7 +203,7 @@ class AbstractParameter(object):
                     if not 'choices' in kwargs: kwargs['choices'] = {}
                     kwargs['choices'][subtag.attrib['id']] = subtag.text
                     if 'selected' in subtag.attrib and (subtag.attrib['selected'] == '1' or subtag.attrib['selected'] == 'yes'):
-                        if 'multi' in kwargs and kwargs['multi'] == '1':
+                        if 'multi' in kwargs and kwargs['multi']:
                             if not 'value' in kwargs: kwargs['value'] = []
                             kwargs['value'].append(subtag.attrib['id'])
                         else:
@@ -354,9 +354,12 @@ class ChoiceParameter(AbstractParameter):
         self.delimiter = ","
         self.showall = False
         self.multi = False
-        if not 'value' in kwargs and not 'default' in kwargs:
+        if not 'value' in kwargs and not 'default' in kwargs and (not 'multi' in kwargs or not kwargs['multi']):
             self.value = self.choices[0][0] #no default specified, first choice is default
 
+        if 'multi' in kwargs and kwargs['multi']:
+            self.value = []
+
         for key, value in kwargs.items():
             if key == 'multi':
                 self.multi = bool(value) #boolean
@@ -372,15 +375,23 @@ class ChoiceParameter(AbstractParameter):
 
     def validate(self,values):
         self.error = None
-        if not isinstance(values,list):
+        if not isinstance(values,list) and not isinstance(values, tuple):
             values = [values]
+        if not self.multi and len(values) > 1:
+            self.error = "Multiple values were specified, but only one is allowed!"
+            return False
         for v in values:
             if not v in [x[0] for x in self.choices]:
-                self.error = "Selected value was not an option!"
+                self.error = "Selected value was not an option! (" + str(v) + ")"
                 return False
         return True
 
 
+    def set(self, value):
+        if self.multi:
+            if not isinstance(value,list) and not isinstance(value, tuple):
+                value = [value]
+        return super(ChoiceParameter,self).set(value)
 
     def compilearg(self):
         """This method compiles the parameter into syntax that can be used on the shell, such as -paramflag=value"""
